@@ -1,6 +1,6 @@
 /*
-   Buttons To Press 6.1
-   Martin "Sam" Samuelsson, sam@home.se, 2002-01-01
+   Buttons To Press 6.2
+   Martin "Sam" Samuelsson, sam@home.se, 2002-01-02
    A mostly-no-frills FLTK GUI for rc, made specially for use with
    the Agenda PDA by Agenda Computing.
 
@@ -43,7 +43,7 @@
 #include <sys/wait.h>
 
 #define D_WIDTH 160
-#define D_HEIGHT 224
+#define D_HEIGHT 240
 #define R_WIDTH 160
 #define R_HEIGHT 100
 #define R_BORDER 2
@@ -102,8 +102,10 @@ FILE *rcfile;
 Fl_Button *button[100];	 // This is the max under irremote
 char command[100][40];
 char t[1024]; 		 // 80 characters my ASS!
+                         // *grin* Ok!
 int nextButton = 0;
-
+int labelsize = 10;
+ int show_toolbar = 1;
 
 	if (!(rcfile = fopen("remote.ini", "r"))) 
 	{
@@ -111,10 +113,31 @@ int nextButton = 0;
 		exit(-1);
 	}
 
-	Fl_App_Window *btpwindow = WidgetFactory::new_window("BTP 6.1");
+	Fl_App_Window *btpwindow = WidgetFactory::new_window("BTP 6.2");
 	
+	Fl_Group *btpgroup = new Fl_Group(btpwindow->x(), btpwindow->y(), btpwindow->w(), btpwindow->h());
+	btpgroup->window()->resizable(btpgroup);
 	while (fgets(t, 1024, rcfile))
 	{
+
+		if (!strncasecmp(t, "toolbar", 7))
+		{
+			char *parseable = index(t, '=') + 1;
+			
+			if (!strncasecmp(parseable, "show", 4)) {
+			  show_toolbar = 1;
+			} else {
+			  show_toolbar = 0;
+			}
+		}
+
+		if (!strncasecmp(t, "labelsize", 9))
+		{
+			char *parseable = index(t, '=') + 1;
+			
+			labelsize = atoi(strtok(parseable, ",\n"));
+		}
+
 		if (!strncasecmp(t, "button", 6))
 		{
 			char *parseable = index(t, '=') + 1;
@@ -130,19 +153,24 @@ int nextButton = 0;
 			sprintf(command[nextButton], "SEND_ONCE %s %s", remote, remoteCode);
 
 			button[nextButton] = new Fl_Button(x, y, width, height, label);
+			button[nextButton]->labeltype(FL_SYMBOL_LABEL);
+			button[nextButton]->labelsize(labelsize);
 			button[nextButton]->callback(cb_button, command[nextButton]);
 
 			nextButton++;
 		}
 	}
-   
-   btpwindow->end();
-	/*
-   Fl_Dockable_Window* toolbar = WidgetFactory::new_toolbar();
-   Widget_Factory::new_button("Done", cb_done, btpwindow);
-   btpwindow->add_dockable(toolbar, 1);
-   toolbar->end();  
-	*/
-   btpwindow->show();   
-   return Fl::run();
+	btpgroup->end();
+	//	btpwindow->end();
+
+	if(show_toolbar) {
+	  Fl_Dockable_Window* toolbar = WidgetFactory::new_toolbar();
+	  Widget_Factory::new_button("Done", cb_done, btpwindow);
+	  btpwindow->add_dockable(toolbar, 1);
+	  toolbar->end();  
+	}
+
+	btpwindow->end();
+	btpwindow->show();   
+	return Fl::run();
 }
